@@ -68,8 +68,11 @@ Plot.CA <- function(CA, titles = NA, xlabel = NA, ylabel = NA,
        type = "n", # nao plota pontos
        xlab = "Order of the components", 
        ylab = "Variance",
+       xaxt = "n", # tira o eixo x
        main = titles[1])
   
+  axis(1, c(1:length(CA$mtxAutvlr[,1])), c(1:length(CA$mtxAutvlr[,1])))
+  
   if (grid) {
     
      args <- append(as.list(par('usr')), c('gray93','gray93'))
