@@ -67,7 +67,10 @@ Plot.FA <- function(FA, titles = NA, xlabel = NA, ylabel = NA, size = 1.1,
        type = "n", # nao plota pontos
        xlab = "Order of the factors", 
        ylab = "Variance",
-       main = titles[1])  
+       xaxt = "n", # tira o eixo x
+       main = titles[1])
+  
+  axis(1, c(1:length(FA$mtxvar[,1])), c(1:length(FA$mtxvar[,1])))
   
   if (grid) {
     
