@@ -65,8 +65,11 @@ Plot.PCA <- function(PC, titles = NA, xlabel = NA, ylabel = NA, size = 1.1,
        type = "n", # nao plota pontos
        xlab = "Order of the components", 
        ylab = "Variance",
+       xaxt = "n", # tira o eixo x
        main = titles[1])
   
+  axis(1, c(1:length(PC$mtxAutvlr[,1])), c(1:length(PC$mtxAutvlr[,1])))
+  
   if (grid) {
     
      args <- append(as.list(par('usr')), c('gray93','gray93'))
